decoder_to_vec

Function decoder_to_vec 

pub(crate) fn decoder_to_vec<T>(
    decoder: impl ImageDecoder,
) -> ImageResult<Vec<T>>
where T: Primitive + Pod,
Reads all of the bytes of a decoder into a Vec. No particular alignment of the output buffer is guaranteed.

Panics if there isn’t enough memory to decode the image.