pub(crate) struct ImageReadBuffer {
scanline_bytes: usize,
buffer: Vec<u8>,
consumed: usize,
total_bytes: u64,
offset: u64,
}Fields
scanline_bytes: usizebuffer: Vec<u8>consumed: usizetotal_bytes: u64offset: u64Implementations
Sourceimpl ImageReadBuffer
impl ImageReadBuffer
Sourcepub(crate) fn new(scanline_bytes: u64, total_bytes: u64) -> Self
pub(crate) fn new(scanline_bytes: u64, total_bytes: u64) -> Self
Create a new ImageReadBuffer.
Panics if scanline_bytes doesn’t fit into a usize, because that would mean reading anything
from the image would take more RAM than the entire virtual address space. In other words,
actually using this struct would instantly OOM so just get it out of the way now.
pub(crate) fn read<F>( &mut self, buf: &mut [u8], read_scanline: F, ) -> Result<usize>