pub(crate) fn decoder_to_vec<T>(
decoder: impl ImageDecoder,
) -> ImageResult<Vec<T>>Expand description
Reads all of the bytes of a decoder into a Vec
Panics if there isn’t enough memory to decode the image.
pub(crate) fn decoder_to_vec<T>(
decoder: impl ImageDecoder,
) -> ImageResult<Vec<T>>Reads all of the bytes of a decoder into a Vec
Panics if there isn’t enough memory to decode the image.